#
# spec file for package python-sphinxcontrib-httpdomain
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-sphinxcontrib-httpdomain
Version:        1.7.0
Release:        lp152.1.1
Summary:        Sphinx domain for HTTP APIs
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/sphinx-contrib/httpdomain
Source:         https://github.com/sphinx-contrib/httpdomain/archive/%{version}.tar.gz
BuildRequires:  %{python_module Flask >= 0.11}
BuildRequires:  %{python_module Sphinx >= 1.5}
BuildRequires:  %{python_module bottle >= 0.11.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module tornado >= 4.5}
BuildConflicts: %{python_module tornado >= 5}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Sphinx >= 1.5
Requires:       python-six
Requires:       python-tornado >= 4.5
Conflicts:      python-tornado >= 5
BuildArch:      noarch
%python_subpackages

%description
This contrib extension, sphinxcontrib.httpdomain provides a Sphinx
domain for describing RESTful HTTP APIs.

You can find the documentation from the following URL:

http://packages.python.org/sphinxcontrib-httpdomain/

%prep
%setup -q -n httpdomain-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest test

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/sphinxcontrib/autohttp/
%{python_sitelib}/sphinxcontrib/httpdomain.py*
%pycache_only %{python_sitelib}/sphinxcontrib/__pycache__
%{python_sitelib}/sphinxcontrib_httpdomain-%{version}-py*-nspkg.pth
%{python_sitelib}/sphinxcontrib_httpdomain-%{version}-py*.egg-info

%changelog
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Use better way to handle tornado version compatibility.
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Don't allow python-tornado >= 5
* Wed Jul  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Sort out a bit to pass the tests again
* Tue Apr 23 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0 (bsc#1139695)
  * Implemented :autoquickref: option that use available
    informations to build a quickref.
  * Remove references to the sphinx.util.compat module which was
    deprecated in Sphinx 1.6 and removed in 1.7.
  * Made :mod:`sphinxcontrib.autohttp.tornado` compatible with
    Tornado 4.5 and newer.
  * Minimum compatible version of Sphinx became changed to 1.5.
  * Use HTTPS for :rfc: generated links.
- Dropped obsolete patch newer-sphinx.patch
- Take upstream release tarball because of tests
* Mon Dec 10 2018 Matej Cepl <mcepl@suse.com>
- Fix %%pycache_only in %%files
* Fri Dec  7 2018 Matej Cepl <mcepl@suse.com>
- Remove wrong BR on python-sphinxcontrib
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Sep 18 2017 toddrme2178@gmail.com
- Use new python-sphinxcontrib package to provide namespace
  directory.
* Mon Sep 18 2017 toddrme2178@gmail.com
- Specify files to guarantee namespace package doesn't conflict
  with python(2|3)-Sphinx
* Wed Jul  5 2017 tbechtold@suse.com
- add newer-sphinx.patch. Needed to make httpdomain working with
  Sphinx >= 1.6 .
* Wed Jul  5 2017 tbechtold@suse.com
- convert to singlespec
* Mon Nov 14 2016 dmueller@suse.com
- update to 1.5.0
* Wed Jul 27 2016 buschmann23@opensuse.org
- update to version 1.4.0
  * Added 429 Too Many Requests as a valid http:statuscode.
    [pull request #81 by DDBReloaded]
  * Became to not resolve references if they can’t be resolved.
    [pull request #87 by Ken Robbins]
  * Became to preserve endpoint ordering when :endpoints: option is
    given. [pull request #88 by Dan Callaghan]
  * Added status codes for WebDAV. [pull request #92 by Ewen
    Cheslack-Postava]
  * Added CORS headers. [pull request #96 by Tomi Pieviläinen]
  * Now sphinxcontrib.autohttp.flask supports multiple paths for
    endpoints using same HTTP method. [pull request #97 by Christian
    Felder]
* Tue Sep 16 2014 tbechtold@suse.com
- update to version 1.3.0:
  * jsonparameter/jsonparam/json became deprecated and split into
    reqjsonobj/reqjson/<jsonobj/<json and reqjsonarr/<jsonarr.
    [issue #55, pull request #72 by Alexander Shorin]
  * Support synopsis (short description in HTTP index), deprecation
    and noindex options for resources.
    [issue #55, pull request #72 by Alexander Shorin]
  * Stabilize order of index items.
    [issue #55, pull request #72 by Alexander Shorin]
  * Added :rst:directive:`http:any` directive and
    http:any role for ANY method.
    [issue #55, pull request #72 by Alexander Shorin]
  * Added :rst:directive:`http:copy` directive and http:copy role
    for COPY method.
    [issue #55, pull request #72 by Alexander Shorin]
  * Added http:header role that also creates reference to the
    related specification.
    [issue #55, pull request #72 by Alexander Shorin]
  * http:statuscode role became to provide references to
    specification sections.
    [issue #55, pull request #72 by Alexander Shorin]
  * Fixed Python 3 incompatibility of autohttp.tornado.
    [pull request #61 by Dave Shawley]
* Tue Jun 24 2014 dmueller@suse.com
- update to 1.2.1:
  * Six support
* Mon Oct 21 2013 dmueller@suse.com
- update to 1.2.0:
  * Add tornado support
* Thu Aug  8 2013 dmueller@suse.com
- update to 1.1.9:
  * Add sphinx.ext.autodoc-style HTTP API reference builder (from Bottle)
* Mon May 13 2013 dmueller@suse.com
- update to 1.1.8:
  * Added better support for docstrings in flask.views.MethodView
  * Added jsonparameter along side form and query parameters.
  * Fixed issue with undefined Value and umethod variables.
  * Now http Pygments lexer can Handle continuous header lines well.
  * Added undoc-blueprints flag option to autoflask directive.
  * Fixed issue #29, a bug that autoflask directive raised
  UnicodeDecodeError when it contains non-ASCII characters.
  * Added endpoints flag option to autoflask directive.
* Thu Nov 15 2012 saschpe@suse.de
- Initial version
